#include "AT898252.H"
#include "lcd.h"
#include "service.h"

///////////////////////
//
//  Port Configuration
//	
//  PIN			SIGNAL
//   0			DB4
//	 1			DB5
//	 2			DB6
//	 3			DB7
//	 4			R/W
//	 5			RS
//   6			E


char en_=1<<6;
char rw=1<<4;
char rs=1<<5;

#define LCD_PORT P3
extern char i;

// send nibble
void send_tetr(char cmd)
{
	i=30;

	LCD_PORT=cmd;
	LCD_PORT=cmd|en_;
	while (i--);
	LCD_PORT=cmd;
}
// send char to LCD	
void lcd_send_char(char c)
{
	send_tetr(c>>4 | rs);
	send_tetr((c&0xF)|rs);
}
// send command to LCD	
void lcd_send_cmd(char c)
{
	send_tetr(c>>4);
	send_tetr(c&0xF);
}

// Send zero-terminated string to LCD
void lcd_send_str(char *sz)
{
	register char i=0;

	P1_1=0;
	while (sz[i])
		lcd_send_char(sz[i++]);
	P1_1=1;
	P1_0=0;
	while (i++<40)
		lcd_send_char(' ');
	P1_0=1;
}

// Clear lcd and print string
void lcd_print(char *sz)
{
	lcd_clear();
	lcd_send_str(sz);
}

// clear LCD
void lcd_clear(void)
{
	lcd_send_cmd(1);
	while (lcd_read_busy()&(1<<7));	// while busy do not return;
}

// read BUSY flag
char lcd_read_busy(void)
{
	char cmd;
	char res=0;
	
	cmd=0x0F;	
// read HI part
	LCD_PORT=cmd|rw|en_;
	res=LCD_PORT<<4;
	LCD_PORT=cmd|rw;
//read LO part
	LCD_PORT=cmd|rw|en_;
	res=res|(LCD_PORT&0x0F);
	LCD_PORT=cmd|rw;

	return res;
}

//inizialize LCD
void lcd_init(void)
{
	/* NOTE ! in the beginning LCD is in 8 bit interface mode, that is why send_tetr
	/ functions are used.*/

	char cmd;
	int j;
	//1 startup
	cmd=3;
	send_tetr(cmd);

	// wait 4.1 ms
	j=2000;
	while (j--);


	//2 startup
	cmd=3;
	send_tetr(cmd);

	// wait 100 mks
	i=50;
	while (i--);
	
	
	//3 startup
	cmd=3;
	send_tetr(cmd);
	
	// 4 bit interface mode
	send_tetr(2);
	
	// font and lines
	lcd_send_cmd(8|32);
	
	// display on/off
	lcd_send_cmd(8|4);// display on, cursor & blink off |2 - cursor on, |1 - blink on	
	
	// shift cursor right
	lcd_send_cmd(4|2);
	
	//clear display
	lcd_send_cmd(1);
}
