#include "service.h"
#include "AT898252.H"
#include "lcd.h"
#include "string.h"
#include "1Wire.h"
#include "stdio.h"

extern char i;
extern char sz[17];
extern const lcd_str code MenuText[9];
extern const handler code aMenuHandlers[9];

// Menu routine
void display_menu(char iItems, char iCurItem)
{
	// current item - is the item displayed in the first line

	lcd_clear();
	lcd_send_str(MenuText[iCurItem]);
	if (iCurItem<iItems)
		lcd_send_str(MenuText[iCurItem+1]);
}

// menu control routine
void menu(char iItems) reentrant
{
	char curItem=0;
	char n;
	unsigned int k=0;


	// display menu contents
start:
	display_menu(iItems,curItem);

	while (1)
	{
		do
		{
			if (QueryTouch())	// query touchpad
				goto start;		// refresh menu
			n=getkey();			// query keyboard
		}
		while  (n==-1);

		if (n==0)
			return;
		
		if (n==10)	// previous line
		{
			if (curItem>0)
				curItem--;
			goto start;
		}
		
		if (n==11)	// next line
		{
			if ((iItems-2)>curItem)
				curItem++;
			goto start;
		}
		
		if (n<=iItems)
		{
			k=0;
			while (++k!=1000)
			{
			   if (QueryTouch()==1)
			   {
					aMenuHandlers[n-1]();	// call corresponding handler
					goto start;
			   }
			}
		}
	}
}

// convert string to Int
char atoc (char* sz,char len)
{
	register char res=0;
	register char i=0;
	char tmp1;
	char tmp2;

	while (len--)
	{
		tmp1=1;
		tmp2=len;
		while (tmp2--)
			tmp1*=10;
		
		res+=(tmp1*(sz[i++]-'0'));
	}

	return res;
}

// read keyboard and return key-kode if it is pressed
char getkey(void)
{
	char ret;
	char release;

  	P2=0;

	release=0x7E;
	P2=release;
	switch (P2)
	{
		case 0x76:
			ret=1;
			goto end;
		case 0x6E:
			ret=4;
			goto end;
		case 0x5E:
			ret=7;
			goto end;
		case 0x3E:
			ret=10;
			goto end;
	}
	
	release=0x7D;
	P2=release;
	switch (P2)
	{
		case 0x75:
			ret=2;
			goto end;
		case 0x6D:
			ret=5;
			goto end;
		case 0x5D:
			ret=8;
			goto end;
		case 0x3D:
			ret=0;
			goto end;
	}

	release=0x7B;
	P2=release;
	switch (P2)
	{
		case 0x73:
			ret=3;
			goto end;
		case 0x6B:
			ret=6;
			goto end;
		case 0x5B:
			ret=9;
			goto end;
		case 0x3B:
			ret=11;
			goto end;
	}
	WMCON|=WDTRST_;  //reset watchdog
	return -1;
end:
	P1_1=0;
	while (P2!=release);
	P1_1=1;

	WMCON|=WDTRST_;  //reset watchdog

	return ret;
}
// display message box and wait until user will press a key
char xmessagebox(char *sz)
{
	register char temp=0;

	if (strlen(sz)>16)
	{
		temp=sz[16];
		sz[16]=0;
	}
	lcd_print(sz);
	
	if (temp)
	{
		sz[16]=temp;
		lcd_send_str(&sz[16]);
	}	
	return readkey();
}

//  wait until user presses a key
char readkey(void)
{	
	char n;
	do
		n=getkey();
	while (n==-1);

	return n;
}
// Init routine
void init(void)
{
	// Watchdog Enable, set prescaler setting,
	WMCON|=WDTEN_|PS0_|PS1_|PS2_|WDTRST_;
	P0=0x8F;	
	P0_2=0;			// LED On
	P3=0;			// 1-Wire - LOW
	P0_3=0;			// Open Door
	lcd_init();		// Initi LCD
	P0_2=1;			// Close LED off
	P0_3=1;			// Close Dooe
}

